# SOP-{{ACID}}: {{TITLE}}

**Applies to:** {{PREFIX}} project
**Last updated:** {{DATE}}
**Last reviewed:** {{DATE}}
**Status:** Active

---

## What Is It?

<description>

---

## Steps

1. **Step 1** — description

---

## Change History

| Date | Change | By |
|------|--------|----|
| {{DATE}} | Initial version | — |
